@@ -37,8 +37,6 @@ static enum mympd_cmd_acl_entity mympd_cmd_acl[] = {
     [INTERNAL_API_FOLDERART] = API_INTERNAL | API_MYMPD_ONLY,
     [INTERNAL_API_JUKEBOX_CREATED] = API_INTERNAL | API_SCRIPT | API_MYMPD_ONLY,
     [INTERNAL_API_JUKEBOX_ERROR] = API_INTERNAL | API_SCRIPT | API_MYMPD_ONLY,
-    [INTERNAL_API_JUKEBOX_REFILL] = API_INTERNAL | API_MYMPD_ONLY,
-    [INTERNAL_API_JUKEBOX_REFILL_ADD] = API_INTERNAL | API_MYMPD_ONLY,
     [INTERNAL_API_PLAYLISTART] = API_INTERNAL | API_MYMPD_ONLY,
     [INTERNAL_API_RAW] = API_INTERNAL | API_MYMPD_ONLY,
     [INTERNAL_API_SCRIPT_EXECUTE] = API_INTERNAL | API_SCRIPT_THREAD,
@@ -82,6 +80,8 @@ static enum mympd_cmd_acl_entity mympd_cmd_acl[] = {
     [MYMPD_API_JUKEBOX_CLEARERROR] = API_PUBLIC | API_MYMPD_ONLY,
     [MYMPD_API_JUKEBOX_LENGTH] = API_PUBLIC | API_MYMPD_ONLY,
     [MYMPD_API_JUKEBOX_LIST] = API_PUBLIC,
+    [MYMPD_API_JUKEBOX_REFILL] = API_PUBLIC | API_MYMPD_ONLY,
+    [MYMPD_API_JUKEBOX_REFILL_ADD] = API_PUBLIC | API_MYMPD_ONLY,
     [MYMPD_API_JUKEBOX_RESTART] = API_PUBLIC,
     [MYMPD_API_JUKEBOX_RM] = API_PUBLIC | API_MYMPD_ONLY,
     [MYMPD_API_LAST_PLAYED_LIST] = API_PUBLIC,
