@@ -36,6 +36,7 @@ enum config_item {
     CI_ACL = 0,
     CI_ALBUM_GROUP_TAG,
     CI_ALBUM_MODE,
+    CI_ALBUM_UNKNOWN,
     CI_CA_CERT_STORE,
     CI_CACHE_COVER_KEEP_DAYS,
     CI_CACHE_HTTP_KEEP_DAYS,
@@ -52,7 +53,6 @@ enum config_item {
     CI_LOGLEVEL,
     CI_MYMPD_URI,
     CI_PIN_HASH,
-    CI_SAVE_CACHES,
     CI_SCRIPTACL,
     CI_SCRIPTS_EXTERNAL,
     CI_SSL,
@@ -63,6 +63,10 @@ enum config_item {
     CI_STICKERS,
     CI_STICKERS_PAD_INT,
     CI_WEBRADIODB,
+    CI_JUKEBOX_QUEUE_LENGTH_SONG,
+    CI_JUKEBOX_QUEUE_LENGTH_SONG_MIN,
+    CI_JUKEBOX_QUEUE_LENGTH_ALBUM,
+    CI_JUKEBOX_QUEUE_LENGTH_ALBUM_MIN,
     CI_COUNT
 };
 
@@ -117,6 +121,7 @@ static const struct t_config_default config_default[] = {
     [CI_ACL]                    = {"acl",                    {.t = CIT_S, .s = ""},             0, 0, vcb_isname},
     [CI_ALBUM_MODE]             = {"album_mode",             {.t = CIT_S, .s = "adv"},          0, 0, vcb_isalnum},
     [CI_ALBUM_GROUP_TAG]        = {"album_group_tag",        {.t = CIT_S, .s = "Date"},         0, 0, vcb_isalnum},
+    [CI_ALBUM_UNKNOWN]          = {"album_unknown",          {.t = CIT_B, .b = false},           0, 0, NULL},
     [CI_CA_CERT_STORE]          = {"ca_cert_store",          {.t = CIT_S, .s = ""},             0, 0, vcb_isfilepath},
     [CI_CACHE_COVER_KEEP_DAYS]  = {"cache_cover_keep_days",  {.t = CIT_I, .i = 31},             CACHE_AGE_MIN, CACHE_AGE_MAX, NULL},
     [CI_CACHE_HTTP_KEEP_DAYS]   = {"cache_http_keep_days",   {.t = CIT_I, .i = 31},             CACHE_AGE_MIN, CACHE_AGE_MAX, NULL},
@@ -130,10 +135,13 @@ static const struct t_config_default config_default[] = {
     [CI_HTTP]                   = {"http",                   {.t = CIT_B, .b = true},           0, 0, NULL},
     [CI_HTTP_HOST]              = {"http_host",              {.t = CIT_S, .s = ""},             0, 0, vcb_isname}, 
     [CI_HTTP_PORT]              = {"http_port",              {.t = CIT_I, .i = 8080},           0, MPD_PORT_MAX, NULL},
+    [CI_JUKEBOX_QUEUE_LENGTH_ALBUM]     = {"jukebox_queue_length_album",     {.t = CIT_I, .i = 25},  5,  250, NULL},
+    [CI_JUKEBOX_QUEUE_LENGTH_ALBUM_MIN] = {"jukebox_queue_length_album_min", {.t = CIT_I, .i = 5},   5, 125, NULL},
+    [CI_JUKEBOX_QUEUE_LENGTH_SONG]      = {"jukebox_queue_length_song",      {.t = CIT_I, .i = 100}, 10, 1000, NULL},
+    [CI_JUKEBOX_QUEUE_LENGTH_SONG_MIN]  = {"jukebox_queue_length_song_min",  {.t = CIT_I, .i = 10},  10, 500, NULL},
     [CI_LOGLEVEL]               = {"loglevel",               {.t = CIT_I, .i = CFG_MYMPD_LOGLEVEL},  LOGLEVEL_MIN, LOGLEVEL_MAX, NULL},
     [CI_MYMPD_URI]              = {"mympd_uri",              {.t = CIT_S, .s = "auto"},         0, 0, vcb_isname},
     [CI_PIN_HASH]               = {"pin_hash",               {.t = CIT_S, .s = ""},             0, 0, vcb_isalnum},
-    [CI_SAVE_CACHES]            = {"save_caches",            {.t = CIT_B, .b = true},           0, 0, NULL},
     [CI_SCRIPTACL]              = {"scriptacl",              {.t = CIT_S, .s = "+127.0.0.0/8"}, 0, 0, vcb_isname},
     [CI_SCRIPTS_EXTERNAL]       = {"scripts_external",       {.t = CIT_B, .b = false},          0, 0, NULL},
     [CI_SSL]                    = {"ssl",                    {.t = CIT_B, .b = true},           0, 0, NULL},
@@ -162,8 +170,6 @@ void mympd_config_free(struct t_config *config) {
     FREE_SDS(config->workdir);
     // Configuration
     FREE_SDS(config->acl);
-    FREE_SDS(config->album_mode);
-    FREE_SDS(config->album_group_tag);
     FREE_SDS(config->ca_certs);
     FREE_SDS(config->ca_cert_store);
     FREE_SDS(config->custom_css);
@@ -194,8 +200,6 @@ void mympd_config_defaults_initial(struct t_config *config) {
     config->startup_time = time(NULL);
     //set all other sds strings to NULL
     config->acl = NULL;
-    config->album_mode = NULL;
-    config->album_group_tag = NULL;
     config->ca_certs = NULL;
     config->ca_cert_store = NULL;
     config->custom_css = NULL;
@@ -225,10 +229,6 @@ static void set_config(struct t_config *config, enum config_item ci, struct t_co
             assert(value->t == CIT_B);
             config->http = value->b;
             break;
-        case CI_SAVE_CACHES:
-            assert(value->t == CIT_B);
-            config->save_caches = value->b;
-            break;
         case CI_SSL:
             assert(value->t == CIT_B);
             config->ssl = value->b;
@@ -287,11 +287,17 @@ static void set_config(struct t_config *config, enum config_item ci, struct t_co
             break;
         case CI_ALBUM_MODE:
             assert(value->t == CIT_S);
-            config->album_mode = value->s;
+            config->albums.mode = parse_album_mode(value->s);
+            FREE_SDS(value->s);
             break;
         case CI_ALBUM_GROUP_TAG:
             assert(value->t == CIT_S);
-            config->album_group_tag = value->s;
+            config->albums.group_tag = mpd_tag_name_iparse(value->s);
+            FREE_SDS(value->s);
+            break;
+        case CI_ALBUM_UNKNOWN:
+            assert(value->t == CIT_B);
+            config->albums.unknown = value->b;
             break;
         case CI_HTTP_HOST:
             assert(value->t == CIT_S);
@@ -337,6 +343,22 @@ static void set_config(struct t_config *config, enum config_item ci, struct t_co
             assert(value->t == CIT_S);
             config->custom_js = value->s;
             break;
+        case CI_JUKEBOX_QUEUE_LENGTH_SONG:
+            assert(value->t == CIT_I);
+            config->jukebox_queue_length_song = (unsigned)value->i;
+            break;
+        case CI_JUKEBOX_QUEUE_LENGTH_SONG_MIN:
+            assert(value->t == CIT_I);
+            config->jukebox_queue_length_song_min = (unsigned)value->i;
+            break;
+        case CI_JUKEBOX_QUEUE_LENGTH_ALBUM:
+            assert(value->t == CIT_I);
+            config->jukebox_queue_length_album = (unsigned)value->i;
+            break;
+        case CI_JUKEBOX_QUEUE_LENGTH_ALBUM_MIN:
+            assert(value->t == CIT_I);
+            config->jukebox_queue_length_album_min = (unsigned)value->i;
+            break;
         case CI_COUNT:
             assert(NULL);
             // This should not occur
@@ -429,11 +451,15 @@ bool mympd_config_read(struct t_config *config) {
         config->ssl_key = sdscatfmt(sdsempty(), "%S/%s/server.key", config->workdir, DIR_WORK_SSL);
     }
 
-    // Parse album configuration
-    config->albums.mode = parse_album_mode(config->album_mode);
-    config->albums.group_tag = mpd_tag_name_iparse(config->album_group_tag);
-    FREE_SDS(config->album_mode);
-    FREE_SDS(config->album_group_tag);
+    // Enforce jukebox queue length's
+    if (config->jukebox_queue_length_album <= config->jukebox_queue_length_album_min) {
+        MYMPD_LOG_ERROR(NULL, "Jukebox album queue length must be greater than minimum");
+        config->jukebox_queue_length_album_min = config->jukebox_queue_length_album / 2;
+    }
+    if (config->jukebox_queue_length_song <= config->jukebox_queue_length_song_min) {
+        MYMPD_LOG_ERROR(NULL, "Jukebox song queue length must be greater than minimum");
+        config->jukebox_queue_length_song_min = config->jukebox_queue_length_song / 2;
+    }
 
     return true;
 }
