@@ -116,7 +116,8 @@ sds mympd_api_album_detail(struct t_mympd_state *mympd_state, struct t_partition
                 if (sticker.mympd[STICKER_LAST_PLAYED] > last_played_max) {
                     last_played_max = (time_t)sticker.mympd[STICKER_LAST_PLAYED];
                     last_played_song_uri = sds_replace(last_played_song_uri, mpd_song_get_uri(song));
-                    last_played_song_title = sds_replace(last_played_song_title, mpd_song_get_tag(song, MPD_TAG_TITLE, 0));
+                    sdsclear(last_played_song_title);
+                    last_played_song_title = mympd_client_get_tag_value_string(song, MPD_TAG_TITLE, last_played_song_title);
                     last_played_song_pos = entities_returned - 1;
                 }
                 sticker_struct_clear(&sticker);
