@@ -58,8 +58,7 @@ static void mongoose_log(char ch, void *param);
  */
 struct mg_mgr *webserver_init_mgr(struct t_config *config, struct t_mg_user_data *mg_user_data) {
     //init mongoose mgr
-    mg_log_set(1);    //set mongoose loglevel to error
-    //mg_log_set(4);  //set mongoose loglevel to debug
+    mg_log_set(MG_LL_ERROR);
     mg_log_set_fn(mongoose_log, NULL);
     struct mg_mgr *mgr = malloc_assert(sizeof(struct mg_mgr));
     mg_mgr_init(mgr);
@@ -138,6 +137,8 @@ void webserver_free(struct mg_mgr *mgr) {
 void *webserver_loop(void *arg_mgr) {
     thread_logname = sdsnew("webserver");
     set_threadname(thread_logname);
+    thread_logline = sdsempty();
+
     struct mg_mgr *mgr = (struct mg_mgr *) arg_mgr;
     MYMPD_LOG_DEBUG(NULL, "Webserver thread is ready");
     // Initially read the queue
@@ -148,6 +149,7 @@ void *webserver_loop(void *arg_mgr) {
     }
     MYMPD_LOG_DEBUG(NULL, "Webserver thread stopped");
     FREE_SDS(thread_logname);
+    FREE_SDS(thread_logline);
     return NULL;
 }
 
@@ -304,6 +306,24 @@ static bool parse_internal_message(struct t_work_response *response, struct t_mg
     return rc;
 }
 
+/**
+ * Handles the data from the MG_EV_WAKEUP event
+ * @param nc Mongoose connection
+ * @param data Received data
+ */
+static void handle_wakeup(struct mg_connection *nc, struct mg_str *data) {
+    switch(data->buf[0]) {
+        case 'Q':
+            read_queue(nc->mgr);
+            break;
+        case 'X':
+            MYMPD_LOG_DEBUG(NULL, "Wakeup mongoose polling");
+            break;
+        default:
+            MYMPD_LOG_ERROR(NULL, "Unhandled wakeup data received");
+    }
+}
+
 /**
  * Central webserver event handler
  * nc->label usage
@@ -324,7 +344,7 @@ static void ev_handler(struct mg_connection *nc, int ev, void *ev_data) {
     switch(ev) {
         case MG_EV_OPEN: {
             if (nc->is_listening) {
-                MYMPD_LOG_DEBUG(NULL, "Listening connection opened");
+                MYMPD_LOG_DEBUG(NULL, "Main listening connection opened");
                 nc->fn_data = NULL;
                 webserver_queue->mg_conn_id = nc->id;
                 webserver_queue->mg_mgr = nc->mgr;
@@ -347,15 +367,7 @@ static void ev_handler(struct mg_connection *nc, int ev, void *ev_data) {
         }
         case MG_EV_WAKEUP: {
             struct mg_str *data = (struct mg_str *) ev_data;
-            assert(data->len == 1);
-            switch(data->buf[0]) {
-                case 'Q':
-                    read_queue(nc->mgr);
-                    break;
-                case 'X':
-                    MYMPD_LOG_DEBUG(NULL, "Wakeup mongoose polling");
-                    break;
-            }
+            handle_wakeup(nc, data);
             break;
         }
         case MG_EV_ACCEPT:
@@ -705,6 +717,9 @@ static void ev_handler_redirect(struct mg_connection *nc, int ev, void *ev_data)
 
     switch(ev) {
         case MG_EV_OPEN:
+            if (nc->is_listening) {
+                MYMPD_LOG_DEBUG(NULL, "Redirect listening connection opened");
+            }
             mg_user_data->connection_count++;
             break;
         case MG_EV_ACCEPT:
